package com.chelvc.framework.feign.interceptor;

import java.io.IOException;
import java.io.InputStream;

import com.chelvc.framework.base.context.Result;
import com.chelvc.framework.common.exception.FrameworkException;
import com.chelvc.framework.common.util.JacksonUtils;
import feign.Response;
import feign.codec.ErrorDecoder;

/**
 * Feign调用异常处理拦截器
 *
 * @author Woody
 * @date 2024/1/30
 */
public class FeignExceptionInterceptor implements ErrorDecoder {
    @Override
    public Exception decode(String method, Response response) {
        Result<?> result;
        try (InputStream input = response.body().asInputStream()) {
            result = JacksonUtils.deserialize(input, Result.class);
        } catch (IOException e) {
            return e;
        }
        return new FrameworkException(result.getCode(), result.getData(), result.getMessage());
    }
}
